<?php declare(strict_types=1);

namespace App\Repository;

use App\Entity\Answer;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;

/**
 * Class AnswerRepository
 * @method find($id, $lockMode = null, $lockVersion = null)
 * @method findAll()
 * @method findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 * @method findOneBy(array $criteria, array $orderBy = null)
 * @package App\Repository
 */
class AnswerRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Answer::class);
    }

    public function findAllByIds(array $ids = []) : array
    {
        return $this
            ->createQueryBuilder('a')
            ->where('a.id IN ?1')
            ->setParameter(1, $ids)
            ->getQuery()
            ->getArrayResult()
        ;
    }

    public function findAllByTopicAndContentType(string $topic, string $contentType) : array
    {
        return $this
            ->createQueryBuilder('a')
            ->leftJoin('a.question', 'q')
            ->leftJoin('q.topic', 't')
            ->where('t.label = ?1 AND q.content_type = ?2')
            ->setParameters([1 => $topic, 2 => $contentType])
            ->getQuery()
            ->getArrayResult()
        ;
    }
}