<?php declare(strict_types=1);

namespace App\Repository;

use App\Entity\Question;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;

/**
 * Class QuestionRepository
 * @package App\Repository
 */
class QuestionRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Question::class);
    }

    public function findAllByTopicExcludeIds(string $topicLabel, array $excludeIds = []) : array
    {
        $qb = $this
            ->createQueryBuilder('q')
            ->leftJoin('q.topic', 't')
            ->where('t.label = ?1')
            ->setParameter(1, $topicLabel)
        ;
        if (count($excludeIds) > 0) {
            $qb->andWhere('q.id NOT IN ?2')->setParameter(2, $excludeIds);
        }

        return $qb->getQuery()->getArrayResult();
    }
}